<?php
/** Cmique Itom (Cmique Itom)
 *
 * @ingroup Language
 * @file
 *
 * @author Ccaxjoj Iteja Z Iti Poop
 * @author SeriCtam
 * @author Teak
 * @author Urhixidur
 */

$messages = array(
# User preference toggles
'tog-underline'               => 'Squóráam linkám:',
'tog-highlightbroken'         => 'Formatan linkám broken <a href="" class="new">janpan</a> (alternative: janpan<a href="" class="internal">?</a>).',
'tog-justify'                 => 'Icáitom paragraphám',
'tog-hideminor'               => 'Camaát editicúnos pac-quimáaxat camjöx cmaa iti',
'tog-extendwatchlist'         => 'Expand listade cáminot zo cohuatlöx jömde quíix applicablix',
'tog-usenewrc'                => 'Camjöx cmaa enhancöx (JavaScript)',
'tog-numberheadings'          => 'Auto-numberom text corridór',
'tog-showtoolbar'             => 'Cohuatlöx ticpatlöx toolbar (JavaScript)',
'tog-editondblclick'          => 'Ticpatlöx páhinám 2 clickám mii (JavaScript)',
'tog-editsection'             => 'Ton ticpatlöx seccion [edit] linkám via',
'tog-editsectiononrightclick' => 'Ton ticpatlöx seccion pok clickám mii<br /> seccion titelám iti (JavaScript)',
'tog-showtoc'                 => 'Cohuatlöx insacualte (páhinám bajlip 3 text corridór mii)',
'tog-rememberpassword'        => 'Qualtiinii he quimx canj jan ordinator iti',
'tog-editwidth'               => 'Cui ticpatlöx janvam',
'tog-watchcreations'          => 'Plusöx páhinám he hun he listade cáminot',
'tog-watchdefault'            => 'Plusöx páhinám he ticpatlöx he listade cáminot',
'tog-watchmoves'              => 'Plusöx páhinám he yacom he listade cáminot',
'tog-watchdeletion'           => 'Plusöx páhinám he delatöx he listade cáminot',
'tog-minordefault'            => 'Jömde ticpatlöx coccebj bajlöxamde auto',
'tog-previewontop'            => "Cohuatlöx cuáxiit boxde ticpatlöx 'pre",
'tog-previewonfirst'          => 'Cohuatlöx cuáxiitde 1. ticpatlöx',
'tog-nocache'                 => 'Necoccebj cachede páhinám',
'tog-enotifwatchlistpages'    => 'E-iitom he páhina he cáminot coccebj quiih',
'tog-enotifusertalkpages'     => 'E-iitom he czaxö páhina he cáminot coccebj quiih',
'tog-enotifminoredits'        => 'E-iitom hede ticpatlöx bajlöxde páhinám',
'tog-enotifrevealaddr'        => 'Xuniim henadressade e-iitom notificacionde e-iitóm',
'tog-shownumberswatching'     => 'Cohuatlöx caitóm cáminotómde numberam',
'tog-fancysig'                => 'Signaturenám brazzinám (sans linkám automaticám)',
'tog-externaleditor'          => 'Usadad ticpatlöx externöx auto',
'tog-externaldiff'            => 'Usadad diff extern auto',
'tog-showjumplinks'           => 'Záj "jumpöx" accessibilitiit linkám',
'tog-uselivepreview'          => 'Usadad cuáxiit live (JavaScript) (Experimentam)',
'tog-forceeditsummary'        => 'Ixuniimticpatlöx he jan nenenterom abvuatlde ticpatlöx',
'tog-watchlisthideown'        => 'Cíiitám he ticpatlöxde listade cáminot zo',
'tog-watchlisthidebots'       => 'Cíiitám botám listade cáminot zo',
'tog-watchlisthideminor'      => 'Cíiitám ticpatlöx nebajlipöxde listade cáminot zo',
'tog-nolangconversion'        => 'Necoccebj convercionde variantám',
'tog-ccmeonemails'            => 'Iitom he copynámde e-iitom he iitomde diijömde caitóm',
'tog-diffonly'                => 'Necohuatlöx contentuade páhina minöxde quiíx.',

'underline-always'  => 'Jömdexepe',
'underline-never'   => 'Diixepe',
'underline-default' => 'AutoBrowser',

# Dates
'sunday'        => 'Dajmino',
'monday'        => 'Luncino',
'tuesday'       => 'Martino',
'wednesday'     => 'Mizxolino',
'thursday'      => 'Ccuetetlino',
'friday'        => 'Virino',
'saturday'      => 'Sabbatino',
'sun'           => 'Daj',
'mon'           => 'Lun',
'tue'           => 'Mar',
'wed'           => 'Miz',
'thu'           => 'Ccu',
'fri'           => 'Vir',
'sat'           => 'Sab',
'january'       => 'Tlacintöx',
'february'      => 'Tlagintöx',
'march'         => 'Tlayitöx',
'april'         => 'Tlanahöntöx',
'may_long'      => 'Tlamacuniltöx',
'june'          => 'Tlachicuaztöx',
'july'          => 'Tlachiconintöx',
'august'        => 'Tlachicunintöx',
'september'     => 'Tlachinucanintöx',
'october'       => 'Tlamantilactöx',
'november'      => 'Tlamantilachintöx',
'december'      => 'Tlamantilacuntöx',
'january-gen'   => 'Tlacintöx',
'february-gen'  => 'Tlagintöx',
'march-gen'     => 'Tlayitöx',
'april-gen'     => 'Tlanahöntöx',
'may-gen'       => 'Tlamacuniltöx',
'june-gen'      => 'Tlachicuaztöx',
'july-gen'      => 'Tlachiconintöx',
'august-gen'    => 'Tlachicunintöx',
'september-gen' => 'Tlachinucanintöx',
'october-gen'   => 'Tlamantilactöx',
'november-gen'  => 'Tlamantilachintöx',
'december-gen'  => 'Tlamantilacuntöx',
'jan'           => 'Tl1',
'feb'           => 'Tl2',
'mar'           => 'Tl3',
'apr'           => 'Tl4',
'may'           => 'Tl5',
'jun'           => 'Tl6',
'jul'           => 'Tl7',
'aug'           => 'Tl8',
'sep'           => 'Tl9',
'oct'           => 'T10',
'nov'           => 'T11',
'dec'           => 'T12',

# Categories related messages
'pagecategories'         => '{{PLURAL:$1|Cajliib|Cajliibám}}',
'category_header'        => 'Páhinám cayliibám zo iti "$1"',
'subcategories'          => 'Subcayliibám',
'category-media-header'  => 'Mediám cayliibám zo iti "$1"',
'category-empty'         => "''Cayliib danjobam nihíl''",
'listingcontinuesabbrev' => 'korb.',

'mainpagetext' => "<big>'''MediaWiki coccebj installöx successua zo mii.'''</big>",

'about'          => 'Miixaz',
'article'        => 'Artículo',
'newwindow'      => '(dansinám precquen)',
'cancel'         => 'Antajöx',
'qbfind'         => 'Hinuetzöx',
'qbbrowse'       => 'Quetzexal',
'qbedit'         => 'Ticpatlöx',
'qbpageoptions'  => 'Jan páhina',
'qbpageinfo'     => 'Contextua',
'qbmyoptions'    => 'Hepáhinám',
'qbspecialpages' => 'Páhinám extravám',
'moredotdotdot'  => 'Tamläj...',
'mypage'         => 'Hepáhina',
'mytalk'         => 'Heczaxö',
'anontalk'       => 'Czaxöde IP',
'navigation'     => 'Navigacion',
'and'            => '&#32;ö',

# Metadata in edit box
'metadata_help' => 'Datade Meta:',

'errorpagetitle'    => 'Römj',
'returnto'          => 'Jumpöx $1.',
'tagline'           => "{{SITENAME}} iti'ab",
'help'              => 'Helpom',
'search'            => 'Yahöx',
'searchbutton'      => 'Yahöx',
'go'                => 'Caátemöx',
'searcharticle'     => 'Caátemöx',
'history'           => 'Historiám páhina',
'history_short'     => 'Historiám',
'updatedmarker'     => 'Par hiineditar visitua ciónsam',
'info_short'        => 'Informacion',
'printableversion'  => 'Cabjöxino printino',
'permalink'         => 'Link permanentöj',
'print'             => 'Printom',
'edit'              => 'Ticpatlöx',
'editthispage'      => 'Ticpatlöx jan páhina',
'delete'            => 'Delarom',
'deletethispage'    => 'Delarom jan páhina',
'undelete_short'    => 'Nedelarom ici {{PLURAL:$1|1 editam|$1 editám}}',
'protect'           => 'Protectom',
'protect_change'    => 'Proteccion quiix',
'protectthispage'   => 'Protectom jan páhina',
'unprotect'         => 'unprotectom',
'unprotectthispage' => 'Unprotectom jan páhina',
'newpage'           => 'Páhina quiih',
'talkpage'          => 'Czaxö jan páhina',
'talkpagelinktext'  => 'Czaxö',
'specialpage'       => 'Páhina extrava',
'personaltools'     => 'Cui personalui',
'postcomment'       => 'Iitom pte queeet',
'articlepage'       => 'Cohuatlöx contentua páhina',
'talk'              => 'Czaxö',
'views'             => 'Cohuatlöxám',
'toolbox'           => 'Caitómam',
'userpage'          => 'Cohuatlöx caitom páhina',
'projectpage'       => 'Cohuatlöx projectua páhina',
'imagepage'         => 'Cohuatlöx ciúchan páhina',
'mediawikipage'     => 'Cohuatlöx iitom páhina',
'templatepage'      => 'Cohuatlöx automii páhina',
'viewhelppage'      => 'Cohuatlöx help páhina',
'categorypage'      => 'Cohuatlöx cayliib páhina',
'viewtalkpage'      => 'Cohuatlöx czaxö',
'otherlanguages'    => 'Itóm pacehuatl iti',
'redirectedfrom'    => '(Meniitomöxde $1)',
'redirectpagesub'   => 'Meniitomöx páhina',
'lastmodifiedat'    => "Jan páhina coccebjöx ticpatlöx iti'ab $2, $1.", # $1 date, $2 time
'viewcount'         => '{{PLURAL:$1|1 ctam|$1 ctám}} coccebj cohuatlöx jan páhina.',
'protectedpage'     => 'Páhina protecta',
'jumpto'            => 'Jumpöx:',
'jumptonavigation'  => 'navigacion',
'jumptosearch'      => 'Yahöx',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => '{{SITENAME}} mii',
'aboutpage'            => 'Project:Miilà',
'copyright'            => 'Contentua coitáamb $1 tan.',
'copyrightpagename'    => 'Copyright {{SITENAME}}',
'copyrightpage'        => '{{ns:project}}:Copyrightám',
'currentevents'        => 'Hualtezxes',
'currentevents-url'    => 'Project:Hualtezxes',
'disclaimers'          => 'Isój cacóomx',
'disclaimerpage'       => 'Project:Isoj cacóomx geniiraloj',
'edithelp'             => 'Help ticpatlöx',
'edithelppage'         => 'Help:Ticpatlöx',
'faq'                  => 'Cocmíiit cmaa',
'faqpage'              => 'Project:Cocmíiit cmaa',
'helppage'             => 'Help:Caálixötöj',
'mainpage'             => 'Caálixötöj',
'mainpage-description' => 'Caálixötöj',
'policy-url'           => 'Project:Cáyun',
'portal'               => 'Portalde ctám',
'portal-url'           => 'Project:Portalde ctám',
'privacy'              => 'Cáyunde privacy',
'privacypage'          => 'Project:Cáyunde privacy',

'badaccess'        => 'Römjde permicion',
'badaccess-group0' => 'Menepermicion executan accion z hecocmíiit.',
'badaccess-groups' => "Accion hecocmíiit coccebj diilimáat czo'd $1.",

'versionrequired'     => 'Vercion $1 MediaWiki pal',
'versionrequiredtext' => 'Vercion $1 MediaWiki pal húpáhinal. cho [[Special:Version]].',

'ok'                      => 'ton',
'retrievedfrom'           => 'Paluatlde "$1"',
'youhavenewmessages'      => 'Mecui $1 ($2).',
'newmessageslink'         => 'huniitóm',
'newmessagesdifflink'     => 'quiixcui',
'youhavenewmessagesmulti' => 'Mecui huniitom $1 iti',
'editsection'             => 'ticpatlöx',
'editold'                 => 'ticpatlöx',
'editsectionhint'         => 'Ticpatlöx partamöx: $1',
'toc'                     => 'Insacualte',
'showtoc'                 => 'cohuatlöx',
'hidetoc'                 => 'cíiitám',
'thisisdeleted'           => 'Cohuatlöx jöx diidelatom $1?',
'viewdeleted'             => 'Cohuatlöx $1?',
'restorelink'             => '{{PLURAL:$1|1 ticpatlöx delatöx|$1 ticpatlöx delatöx}}',
'feedlinks'               => 'Fiiyt:',
'feed-invalid'            => 'Typenamde subscripcion i Fiiyt invalidyt.',
'site-rss-feed'           => '$1 Fiiytde RSS',
'site-atom-feed'          => '$1 Fiiytde Atom',
'page-rss-feed'           => '"$1" Fiiytde RSS',
'page-atom-feed'          => '"$1" Fiiytde Atom',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Páhina',
'nstab-user'      => 'Caitom páhina',
'nstab-media'     => 'Media páhina',
'nstab-special'   => 'Extravam',
'nstab-project'   => 'Projectua páhina',
'nstab-image'     => 'Ciúchan',
'nstab-mediawiki' => 'Iitom',
'nstab-template'  => 'Automii',
'nstab-help'      => 'Help páhina',
'nstab-category'  => 'Cayliib',

# Main script and global functions
'nosuchaction'      => "Ne'dáár accion",
'nosuchactiontext'  => 'Accion apualte URLsan z coccebj nepualat wiki zo san',
'nosuchspecialpage' => "Ne'dáár páhina extrava",
'nospecialpagetext' => "<big>'''Meccan páhina extrava invalida.'''</big>

Meccan páhina extrava valide pac [[Special:SpecialPages]] iti.",

# General errors
'error'                => 'Römj',
'databaseerror'        => 'Römjde database',
'dberrortext'          => 'Römjde syntaxde database query coccebj icmaaniit.
Jan pos-coccebj bug zo software zo iti.
Hunattemptöx database query coccebjöx:
<blockquote><tt>$1</tt></blockquote>
funccion xi "<tt>$2</tt>".
MySQL returnöx römj iti "<tt>$3: $4</tt>".',
'dberrortextcl'        => 'Römjde syntaxde database query coccebj icmaaniit.
Hunattemptöx database query coccebjöx:
"$1"
funccion xi "$2".
MySQL returnöx römj iti "$3: $4"',
'noconnect'            => 'Sorry! Wiki zo expiriencom cy technicy pac ö necontactom serverde database zo. <br />
$1',
'nodb'                 => 'Neselectam database $1',
'cachederror'          => 'Jan coccebj copynam cachenamde páhina Neces ö necoccebj updatenom.',
'laggedslavemode'      => 'Attencion: Páhina necoccebj updatenám cmaa.',
'readonly'             => 'Database protectáme',
'enterlockreason'      => 'Enterom raede lockom zo, includom estimacionde janxepe lockom zo releasom',
'readonlytext'         => "Database zo coccebj locköx cmaade hunticpatlöx, posde maintenancede database, normal returnöx 'depre.

Sysop zo locköx zo xuniim jan rae': $1",
'readonly_lag'         => "Database coccebj locköx auto jan 'slave database serverám' zo ifanomde 'master' zo",
'internalerror'        => 'Römj internal',
'internalerror_info'   => 'Römj internal: $1',
'filecopyerror'        => 'Necopynöx ciúchan "$1" de "$2".',
'filerenameerror'      => 'Nenomöx ciúchan "$1" de "$2".',
'filedeleteerror'      => 'Nedelatomöx ciúchan "$1".',
'directorycreateerror' => 'Necreatöx directoran "$1".',
'filenotfound'         => 'Neyahöx ciúchan "$1".',
'fileexistserror'      => 'Necoccebj caitomde ciúchan "$1": ciúchan coccebj',
'unexpected'           => 'Value neqance: "$1"="$2".',
'formerror'            => 'Römj: nesubmit listade fillöx',
'badarticleerror'      => 'Jan accion neperformon jan páhina iti.',
'cannotdelete'         => 'Nedelatom páhina zo jöx ciúchan zo fillöx. (Jömdectam coccebj delatom jan pos-poop.)',
'badtitle'             => 'Ahisharliit',
'badtitletext'         => 'Zo páhina coccebj ahisharliit zo.
Jan pos-coccebj plusöxde 1 jöx 1 characterám jan nepos-coccebj usadas titlenám iti.',
'perfcached'           => 'Jan data coccebj cache ö necoccebj updatenom.',
'perfcachedts'         => "Jan data coccebj cache ö coccebjöx updatenom $1 'de.",
'querypage-no-updates' => 'Updatenámde jan páhina coccebj disablenöx cmaa. Jan data necanj cmaa.',
'wrong_wfQuery_params' => 'Parameterám incorrectámde wfQuery()<br />
Funccion: $1<br />
Query: $2',
'viewsource'           => 'Cohuatlöx sourcenam',
'viewsourcefor'        => '$1 mii',
'protectedpagetext'    => 'Jan páhina coccebj lockom neticpatlöx pos-poop.',
'viewsourcetext'       => 'Mecohuatlöx ö copynom sourcenam zode jan páhina:',
'protectedinterface'   => "Jan páhina coccebj textuade interface software zo 'de ö coccebj lockom neticpatlöx abusenam.",
'editinginterface'     => "'''Attencion:''' Meticpatlöx páhinám pac, jan usadadde textuade interface software zo 'de. Quiíxde jan páhinám affectom caitominterface zode diijömde caitóm.",
'sqlhidden'            => '(SQL querynam cíiitámöx)',
'cascadeprotected'     => 'Jan páhina coccebj protectöxde ticpatlöx, zo coccebj cascadande jan {{PLURAL:$1|páhina|páhinám}}, jan coccebj protëctox cascadanöx opcion zo mii:
$2',
'namespaceprotected'   => "Me necoccebj permiccion ticpatlöx páhinám '''$1''' ipartuatl zo iti.",
'customcssjsprotected' => 'Me necoccebj permiccion ticpatlöx jan páhina, zo coccebj diijömde caitom quáatlaác.',
'ns-specialprotected'  => 'Páhinámde {{ns:special}} zo iti neticpatlöx.',

# Login and logout pages
'logouttitle'                => 'Caitom cuípo',
'logouttext'                 => "'''Me cuípo.'''<br />
Mecontinudad usadad {{SITENAME}} anon jïx me caápo dajcaitom ö jömcaitom. Páhinám pac continudad displayom dajme caápo, jánclearom mecachede browser.",
'welcomecreation'            => "== Q'$1! ==

Mecaitom coccebj creatöx. Quiix hequáatlaácde {{SITENAME}} pos-poop.",
'loginpagetitle'             => 'Caitom caápo',
'yourname'                   => 'Caitom ID:',
'yourpassword'               => 'Quimx canj:',
'yourpasswordagain'          => 'Vanquimx canj:',
'remembermypassword'         => 'Qualtiinii he quimx canj jan ordinator iti',
'yourdomainname'             => 'Hedomino:',
'externaldberror'            => 'Pos-römjde authenticacionde database extername jöx me necoccebj permiccionde updatan mecaitom externom.',
'login'                      => 'Caápo',
'nav-login-createaccount'    => 'Caápo / xuatl',
'loginprompt'                => 'Henáabliicookám caápo {{SITENAME}}.',
'userlogin'                  => 'Caápo / xuatl',
'logout'                     => 'Cuípo',
'userlogout'                 => 'Cuípo',
'notloggedin'                => 'Necaápo',
'nologin'                    => 'Menecaápo? $1.',
'nologinlink'                => 'Xuatl ö',
'createaccount'              => 'Xuatl',
'gotaccount'                 => 'Mecaápo? $1.',
'gotaccountlink'             => 'Caápo',
'createaccountmail'          => 'caxuatl e-iitom',
'badretype'                  => 'Quimx cánj zo misoj nematchöx.',
'userexists'                 => 'IDde caitom coccebj usadad. Submitom hunnom.',
'youremail'                  => 'E-iitom:',
'username'                   => 'Caitom ID:',
'uid'                        => 'ID comháars:',
'yourrealname'               => 'Comcáacuatl:',
'yourlanguage'               => 'Itom ö:',
'yourvariant'                => 'Ccójbam:',
'yournick'                   => 'Brazzi:',
'badsig'                     => 'Signatura raw invalidaw; checkom HTML tagám.',
'badsiglength'               => 'Brazzi coccebj bajlip; brazzi correctom minusde $1 characterám.',
'email'                      => 'E-iitom',
'prefs-help-realname'        => 'Comcáacuatl coccebj opcional, zo xuniim plusöxde attribucionde menaffortua.',
'loginerror'                 => 'Römjde caápo',
'prefs-help-email'           => 'Adressade e-iitom coccebj opcional, zo enable diijömde caitom contactom me mecaitom jöx meczaxöde caitom sans comcáacuatl ajbul.',
'nocookiesnew'               => 'IDde caitom zo coccebj creatöx, me necaápo. {{SITENAME}} usadad cookie caápo caitóm. Me necoccebj cookie. Enable cookie, caápo quimx canj ö caitom.',
'nocookieslogin'             => '{{SITENAME}} usadad cookie caápo caitóm. Me necoccebj cookie. Enable cookie ö caápo.',
'noname'                     => 'Me necoccebj IDde caitom validom caápospecified.',
'loginsuccesstitle'          => 'Caápo tampua',
'loginsuccess'               => "'''Me coccebj caápo {{SITENAME}} itide \"\$1\".'''",
'nosuchuser'                 => 'Jan caitom necoccebj zo, ID "$1". Cohuatlöx mecuáxiit jöx creatom huncaitom.',
'nosuchusershort'            => 'Jan caitom necoccebj zo, ID "<nowiki>$1</nowiki>". Cohuatlöx mecuáxiit.',
'nouserspecified'            => 'Me coccebj IDde caitom caápo.',
'wrongpassword'              => 'Römjde quimx canj. Vanquimx canj.',
'wrongpasswordempty'         => 'Quimx canj blankanj. Vanquimx canj.',
'passwordtooshort'           => 'Mequimx canj coccebj invalidam ö ij. Tonminiimálo $1 charácto ö juaxaltezxuatl.',
'mailmypassword'             => 'Quimx canj e-iitom',
'passwordremindertitle'      => 'Qualtiiniide quiinx canjde {{SITENAME}}',
'passwordremindertext'       => 'Jömdecomcáac (me, adressade IP $1 mii) coccebj iitom hunquimx canjde {{SITENAME}} ($4).
Quimx canj zode caitom "$2" coccebj "$3".
Me caápo ö reset\' mequimx canj cmaa.

Jömdecomcáac coccebj e-iitom zo jöx meraán mequimx canj, menignoran jan iitom ö usadad mejanquimx canj.',
'noemail'                    => 'Zo necoccebj addressade e-iitomde caitom "$1".',
'passwordsent'               => 'Hunquimx anj coccebj iitomde adressade e-iitom registrarde "$1".
Caápo me recevoir depre.',
'blocked-mailpassword'       => 'Menadressade IP coccebj blocköxde ticpatlöx ö necoccebj permiccion usadad quimx canj recovery funccion zode abuse preventua.',
'eauthentsent'               => "E-iitomde confirmacion coccebj iitomde adressade e-iitom the nominatenöx.
Depre diijömde e-iitom coccebj iitomde account zo, me coccebj Necesde instruccions e-iitom zo iti,
confirmom account zo coccebj de'me.",
'throttled-mailpassword'     => 'Qualtiiniide quimx canj zo coccebj iitomöx, hun $1 horás iti. Abuse preventual, nejömde 1 qualtiiniide quimx canj coccebj iitomöxde $1 horás.',
'mailerror'                  => 'Römj iitom e-iitom: $1',
'acct_creation_throttle_hit' => 'Sorry, me creatöx $1 accountám. Zo coccebj max zo.',
'emailauthenticated'         => 'Menadressade e-iitom coccebj authenticatöx $1 iti.',
'emailnotauthenticated'      => 'Menadressade e-iitom necoccebj authenticatöx. 0 e-iitóm coccebj iitomöxde jömde jan funccción.',
'noemailprefs'               => 'Specifan adressade e-iitomde jan fucción enablenan.',
'emailconfirmlink'           => 'Confirmom menadressade e-iitom',
'invalidemailaddress'        => 'Adressade e-iitom zo necoccebj acceptom, zo apparde pos-coccebj format invalidat pac. Enter adressa formatan correctan pac jöx zéro jan space.',
'accountcreated'             => 'Jönneram',
'accountcreatedtext'         => 'Jönneram $1 mii puo.',
'loginlanguagelabel'         => 'Itom: $1',

# Password reset dialog
'resetpass'               => "Account quimx canj'reset",
'resetpass_announce'      => "Me caápo code temp e-iitomöx mii. Fini caápo, me reset' hunquimx canj cmaadexepe:",
'resetpass_header'        => "Reset'quimx canj",
'oldpassword'             => 'Janquimx canj:',
'newpassword'             => 'Hunquimx canj:',
'retypenew'               => 'Vanhunquimx canj:',
'resetpass_submit'        => 'Vanquimx canj ö caápo',
'resetpass_success'       => 'Me quimx canj coccebj quiixde success! Caápo cmaa...',
'resetpass_bad_temporary' => "Quimx canj temp invalidanj. Me coccebj reset' quimx canjde success jöx requestan hunquimx canj temp pac.",
'resetpass_forbidden'     => 'Quimx cánj nereset jan wiki iti',

# Edit page toolbar
'bold_sample'     => 'Text ccomca',
'bold_tip'        => 'Text ccomca',
'italic_sample'   => 'Text canj',
'italic_tip'      => 'Text canj',
'link_sample'     => 'Titelde link',
'link_tip'        => 'Link intern',
'extlink_sample'  => 'http://www.example.com Titelde link',
'extlink_tip'     => 'Link extern (¡hajbazxo http:// ö!)',
'headline_sample' => 'Text corridor',
'headline_tip'    => 'Text corridor 2',
'math_sample'     => 'Heformula cuerte damir',
'math_tip'        => 'Formula mathematatl (LaTeX)',
'nowiki_sample'   => 'Neformattám cuerte damir',
'nowiki_tip'      => 'Neformatöxde wiki',
'image_sample'    => 'Cuáxiit.jpg',
'image_tip'       => 'Plusöx ciúchan zo',
'media_sample'    => 'Cuáxiit.ogg',
'media_tip'       => 'Link MediaCiúchan',
'sig_tip'         => 'Hesignura xeperat epa',
'hr_tip'          => 'I horizont (seperatman)',

# Edit pages
'summary'                   => 'Abvuatl:',
'subject'                   => 'Subject/ccanzam:',
'minoredit'                 => 'Jan coccebj editám z bajlöxám',
'watchthis'                 => 'Cáminot jan páhina',
'savearticle'               => 'Xuniim páhina',
'preview'                   => 'Cuáxiit',
'showpreview'               => 'Cohuatlöx cuáxiit',
'showlivepreview'           => 'Live cuáxiit',
'showdiff'                  => 'Cohuatlöx quiix',
'anoneditwarning'           => "'''Attencion:''' Me necaápo. Menadressade IP coccebj recordöx históriade jan páhina iti.",
'missingsummary'            => "'''Attencion:''' Me necoccebj providöx abvuatlde ticpatlöx zo. Clicköx 'Xuniim páhina' xuniim meticpatlöx sans abvuatlde ticpatlöx.",
'missingcommenttext'        => 'Enterom commentua !-cmaa.',
'missingcommentheader'      => "'''Attencion:''' Me necoccebj providöx subjectua/corridor zode jan commentua. Clickom 'Xuniim páhina' xuniim meticpatlöx sans subjectua/corridor zo.",
'summary-preview'           => 'Cuáxiitde abvuatl:',
'subject-preview'           => 'Cuáxiitde subjectua/corridor:',
'blockedtitle'              => 'Caitom blockámit',
'blockedtext'               => "<big>'''Hexuatl jöx adressade IP cáablockom.'''</big>

Block zo expondal $1. Rasonna zo coccebj: ''$2''.

* Start block zo: $8
* Xanzo block zo: $6
* Jonzicuatl blockam zo: $7

Me contactam $1 jöx pac [[{{MediaWiki:Grouppage-sysop}}|sysop]] discussom iti block zo.
Me nenusor e-iitom päzxo hab' adressade e-iitom validom coccebj [[Special:Preferences|mequáatlaác]] ö'me neblockomde e-iitom.
Me adressa IP coccebj $3 ö ID block z coccebj #$5. Includam 1 jöx 2 pac querinám iti.",
'autoblockedtext'           => "Menadressade IP coccebj blocköx auto. Zo coccebj usadad diijömde caitom miii, jan coccebj blocköxde $1.
Rasonna zo coccebj:

:''$2''

* Start block zo: $8
* Xanzo block zo: $6

Me contactam $1 jöx pac [[{{MediaWiki:Grouppage-sysop}}|sysop]] discussom iti block zo.

Me nenusor e-iitom päzxo hab' adressade e-iitom validom coccebj [[Special:Preferences|mequáatlaác]] ö'me neblockomde e-iitom.

Me IDde block coccebj $5. Includam 1 jöx 2 pac querinám iti.",
'blockedoriginalsource'     => "Sourcenam zode '''$1''' coccebj cohuatlöx:",
'blockededitsource'         => "Textua zode '''meticpatlöxde''' '''$1''' coccebj cohuatlöx:",
'whitelistedittitle'        => 'Caápo Neces ticpatlöx',
'whitelistedittext'         => 'Mecoccebj $1 ticpatlöx páhinám.',
'confirmedittitle'          => 'Confirmacionde e-iitom coccebj Neces ticpatlöx',
'confirmedittext'           => "Me confirmöx menadressade de e-iitom ticpatlöx 'depre. Set' ö validatenan menadressade IP [[Special:Preferences|hequáatlaác]] mii.",
'nosuchsectiontitle'        => "Ne'dáár partam",
'nosuchsectiontext'         => "Me pos-xuniim ticpatlöx ne'dáár partam.  Zo necoccebj ne'dáár partam $1, meticpatlöx necoccebj xuniim.",
'loginreqtitle'             => 'Caápo Neces',
'loginreqlink'              => 'caápo',
'loginreqpagetext'          => 'Zo coccebj Neces $1 cohuatlöx jömde páhinám.',
'accmailtitle'              => 'Iitom quimx canj.',
'accmailtext'               => 'Quimx canj zode "$1" coccebj iitöxde $2.',
'newarticle'                => '(Quiih)',
'newarticletext'            => 'Meclickom linkamde páhina tazo necoccebj zo.
Huants createnom jan páhina, startom type mii box !-cmaa iti
([[{{MediaWiki:Helppage}}|páhinade helpom]] zo viside plus informacion).
Me coccebj römjasi poop, clickom meback-buttonde browser coccebj perfectua.',
'anontalkpagetext'          => "----''Jan coccebj czaxö zode caitomde IDde adressade IP. Isój necoccebj caápo. Jan coccebj rae'de usadadde adressade IP numerical identificacion 'prenisój. Plusöxde caitom pos-coccebj jan adressade IP. Me pos-coccebj anonimo ö commentua irrevelantua coccebj directomde me poop, [[Special:UserLogin|caápo-jande]] exitom confucion diijömde IP-caitóm mii.''",
'noarticletext'             => 'Jan páhina necoccebj textua zo, me pos-coccebj [[Special:Search/{{PAGENAME}}|yahöx jan páhina]] diijömde páhinám iti jöx [{{fullurl:{{FULLPAGENAME}}|action=edit}} ticpatlöx jan páhina].',
'clearyourcache'            => "'''Notificacion:''' Xuniim 'depre, me pos-coccebj bypassöx mecachede browser caitomi quiíx. '''Mozilla / Firefox / Safari:''' quan ti caitomde ''Shift'' zoxepe clickom ''Reload'', jöx cuápook zo ti ''Ctrl-Shift-R'' (''Cmd-Shift-R'' Apple Mac iti); '''IE:''' quan ti ''Ctrl'' zoxepe clickom ''Refresh'', jöx cuápook zo ti ''Ctrl-F5''; '''Konqueror:''': clickom buttonde ''Reload'' zo, jöx cuápook zo iti ''F5''; '''Opera''' caitóm pos-coccebj clairomde cache completementua ''Tools→Preferences'' iti.",
'usercssjsyoucanpreview'    => "'''Tip:''' Usadad 'Cohuatlöx cuáxiit' testom me hun CSS/JS xuniim 'depre.",
'usercsspreview'            => "'''He cuáxiit he CSSde caitom, zo necoccebj xuniim!'''",
'userjspreview'             => "'''He cuáxiit/testom he JavaScriptde caitom, zo necoccebj xuniim!'''",
'userinvalidcssjstitle'     => "'''Attencion:''' Skin \"\$1\" coccebj ne'dáár. Regardom .css ö .js páhinám usadad titlenam lowercase zo, yanuiíxzo mii yahöxde ti {{ns:user}}:Foo/monobook.css opposadadde {{ns:user}}:Foo/Monobook.css.",
'updated'                   => '(varupdatenám)',
'note'                      => "'''Notificacion:'''",
'previewnote'               => "'''Jan coccebj cuáxiit zo; quiíx necoccebj xuniim!'''",
'previewconflict'           => 'Jan cuáxiit reflectom textua zode upper textua ticpatlöx hant jan coccebj cuáxiitde zuniim páhina.',
'session_fail_preview'      => "'''Sorry! He necoccebj processom meticpatlöx xajvon datade seccion.
Nexajvon. Jan necoccebj naxajvon poop, cuípo ö caápo.'''",
'session_fail_preview_html' => "'''Sorry! He necoccebj processom meticpatlöx xajvon datade seccion.'''

''Jan wiki coccebj HTML raw enablenom, cuáxiit zo coccebj camaátde precaucion JavaScripts caniim.''

'''Jan coccebj ticpatlöx legimatöx poop, reprocessom. Jan necoccebj processom poop, cuípo ö caápo.'''",
'token_suffix_mismatch'     => "'''Meticpatlöx coccebj rejectöx meclient cahöx characteromde punctacion zo ticpatlöx zo iti. TicpatlÖx zo coccebj rejectöxde preventua corrupcionde textuade páhina zo. 
Jan lajxepe occuram me usadad proxy service anon web-based buggy.'''",
'editing'                   => 'Ticpatlöx $1',
'editingsection'            => 'Ticpatlöx $1 (seccion)',
'editingcomment'            => 'Ticpatlöx $1 (commentua)',
'editconflict'              => 'Römjde ticpatlöxde conflictua: $1',
'yourtext'                  => 'Hetext',
'storedversion'             => 'Vercion ráimuniit',
'nonunicodebrowser'         => "'''ATTENCION: Mebrowser necoccebj compliantede 'unicode' (characterám sans huáp ti). Workaround coccebj hant itide me permiccion ticpatlöx páhinám: non-ASCII characterám coccebj codes hexidecimales.'''",
'editingold'                => "'''ATTENCION: Me coccebj ticpatlöx revicion outdatenam zode jan páhina. Me xuniim zo, jömde quiíx hunde jan revicion coccebj delar poop.'''",
'yourdiff'                  => 'Quiíx',
'longpagewarning'           => "'''ATTENCION: Jan páhina coccebj $1 kilobynám; browserám pac pos-coccebj problemámde ticpatlöx páhinám necade jöx plusöxde 32 kb.
Cahöx ticpatlöx jan páhina minöx seccion iti.'''",
'longpageerror'             => "'''RÖMJ: Textua zo mexuniim coccebj $1 kilobytenám, jan coccebj plusöxde maxde $2 kilobytenám. Zo necoccebj xuniim.'''",
'readonlywarning'           => "'''ATTENCION: Database zo coccebj lockomde kyépöx, zo necoccebj posde xuniim meticpatlöx cmaa. Me coccebj considerom ''cut-n-paste'' textua zo ciúchande textua iti ö xuniimde diijömdexepe.'''",
'protectedpagewarning'      => "'''ATTENCION: Jan páhina coccebj lockomde sysopám coccebj ticpatlöx zo permiccional.'''",
'semiprotectedpagewarning'  => "'''Notificacion:''' Jan páhina coccebj lockom caitom registrar coccebj ticpatlöx zo.",
'cascadeprotectedwarning'   => "'''Attencion:''' Jan páhina coccebj lockom jan coccebj ticpatlöxde caitom sysopán permiccion mii, zo coccebj includöx jan {{PLURAL:$1|cascade-páhina|cascade-páhinám}} hun:",
'templatesused'             => 'Automií usadad jan páhina iti:',
'templatesusedpreview'      => 'Automií usadad jan cuáxiit iti:',
'templatesusedsection'      => 'Automií usadad jan seccion iti:',
'template-protected'        => '(protectöx)',
'template-semiprotected'    => '(semi-protectöx)',
'nocreatetitle'             => 'Limiitde creacionde páhinám',
'nocreatetext'              => 'Jan site coccebj avlutuatl altede creatöx hun páhinám.
Me pos-coccebj revertöx ö ticpatlöx janpáhinám jöx [[Special:UserLogin|caápo]].',
'nocreate-loggedin'         => 'Me necoccebj permiccionde creatöx hunpáhinám jan wiki iti.',
'permissionserrors'         => 'Römjde permicción',
'permissionserrorstext'     => "Me necoccebj permiccionde zo, pre'zo {{PLURAL:$1|rae|rae'}}:",

# "Undo" feature
'undo-success' => 'Ticpatlöx zo pos-coccebj iixponintöx. Controlar comparicion zo !-cmaade verifiatom jan coccebj yazuáxiim ö xuniim quiíx zo !-cmaade fini iixponintöx ticpatlöx zo.',
'undo-failure' => 'Ticpatlöx zo necoccebj ticpatlöxde ticpatlöxám iti-am conflictom.',
'undo-summary' => "Iixponintöx revicion $1 'de [[Special:Contributions/$2|$2]] ([[User talk:$2|Czaxö]])",

# Account creation failure
'cantcreateaccounttitle' => 'Nexuatláminop',
'cantcreateaccount-text' => "Creacionde caitomde jan adressade IP ('''$1''') coccebj blockom [[User:$3|$3]] mii.

Rae' zo xuniim $3 mii coccebj ''$2''",

# History pages
'viewpagelogs'        => 'Cohuatlöx logámde jan páhina',
'nohistory'           => 'Jan páhina necoccebj históriade ticpatlöx.',
'currentrev'          => 'Revicion cmaa',
'revisionasof'        => 'Revicionde $1',
'revision-info'       => "Revicionde $1 'de $2", # Additionally available: $3: revision id
'previousrevision'    => '←Janrevicion',
'nextrevision'        => 'Hunrevicion→',
'currentrevisionlink' => 'Revicion currentuanon',
'cur'                 => 'curt',
'next'                => 'hunn',
'last'                => 'hunl',
'page_first'          => 'jann',
'page_last'           => 'janl',
'histlegend'          => "Seleccionde quiíx: xuniim cui radio zode vercion zode comparar ö click 'enter' jöx click bazoniiniitöxamde vyu !-cmaa uisan.<br />
Informacion: (curt) = quiíxde vercion currentua,
(hunl) = quiíxde vercion precedatöxuam, b = ticpatlöx bajlöxam.",
'deletedrev'          => '[ëjmet]',
'histfirst'           => 'Xepe',
'histlast'            => 'Cmaa',
'historysize'         => '($1 bytenám)',
'historyempty'        => '(döjmet)',

# Revision feed
'history-feed-title'          => 'Históriade revicion',
'history-feed-description'    => 'Históriade revicion jande páhina wiki zo iti',
'history-feed-item-nocomment' => '$1 öl $2 mii', # user at time

# Revision deletion
'rev-deleted-comment'     => '(delatom commentua)',
'rev-deleted-user'        => '(delatom nomde caitom)',
'rev-deleted-event'       => '(delatom itinam)',
'rev-delundel'            => 'cohuatlöx/cíiitám',
'revisiondelete'          => 'Delatom/diidelatom revición',
'revdelete-nooldid-title' => 'Necoccebj aimde revicion',
'revdelete-selected'      => "'''{{PLURAL:$2|Revicion selectonde|Revición selectónde}} $1:'''",
'revdelete-legend'        => 'Xuniim restricción',
'revdelete-hide-text'     => 'Camaát textuade revicion',
'revdelete-hide-name'     => 'Camaát accion öjaim',
'revdelete-hide-comment'  => 'Camaát commentuade ticpatlöx',
'revdelete-hide-user'     => 'Camaát IDde caitom/IDde IP',
'revdelete-hide-image'    => 'Cohuatlöx contentua ciúchan',
'revdelete-log'           => 'Commentuade log:',
'revdelete-logentry'      => 'quiixöx revicion visibilitiitde [[$1]]',
'logdelete-logentry'      => 'quiixöx eventua visibilitiitde [[$1]]',

# Diffs
'history-title'           => 'Históriade revicionde "$1"',
'lineno'                  => 'Pozxáat $1:',
'compareselectedversions' => 'Comparenom verción selectón',
'editundo'                => 'iixponintöx',
'diff-multi'              => '({{PLURAL:$1|1 revicion páult|$1 revición páultíi}} necohuatlöx.)',

# Search results
'searchresults'         => 'Resuluámde yahöx',
'searchresulttext'      => 'Plusöxde informaciónde yahöx {{SITENAME}} iti, jumpöx [[{{MediaWiki:Helppage}}|{{int:help}}]].',
'searchsubtitle'        => "Me yahöx '''[[:$1]]''' iti",
'searchsubtitleinvalid' => "Me yahöx '''$1''' iti",
'noexactmatch'          => "'''Páhina zo \"\$1\" coccebj ne'dáár.''' Mecoccebj [[:\$1|hunpáhinámom]].",
'prevn'                 => 'jan $1',
'nextn'                 => 'hun $1',
'viewprevnext'          => 'Cohuatlöx ($1) ($2) ($3)',
'searchhelp-url'        => 'Help:Caálixötöj',
'powersearch'           => 'Yahöx',

# Preferences page
'preferences'           => 'Quáatlaác',
'mypreferences'         => 'Hequáatlaác',
'prefs-edits'           => 'Ticpatlöx jöxualtec ID-cort:',
'prefsnologin'          => 'Necaápo',
'prefsnologintext'      => 'Zo coccebj Neces [[Special:UserLogin|caápo]] quiixom hequáatlaác.',
'qbsettings'            => 'Zuónaát',
'qbsettings-none'       => 'Nepartám',
'changepassword'        => "Reset'quimx canj",
'skin'                  => 'Zuláugaum',
'skin-preview'          => 'Cuáxiit',
'math'                  => 'HTML-cuat',
'dateformat'            => 'Formatumde datum',
'datedefault'           => 'Diiquáatlaac',
'datetime'              => 'Datum ö xepe',
'math_unknown_error'    => 'römj ác',
'math_unknown_function' => 'functión ác',
'math_lexing_error'     => 'römjde lexám',
'math_syntax_error'     => 'römjde syntáx',
'prefs-personal'        => 'Caitom profile',
'prefs-rc'              => 'Camjöx cmaa',
'prefs-watchlist'       => 'Listade cáminot',
'prefs-misc'            => 'Jömc',
'saveprefs'             => 'Xuniim',
'resetprefs'            => "Reset'",
'textboxsize'           => 'Ticpatlöx',
'rows'                  => 'Rowám:',
'columns'               => 'Columnám:',
'searchresultshead'     => 'Yahöx',
'savedprefs'            => 'Hequáatlaác coccebj xuniimöx.',
'timezonelegend'        => 'Zonede xepe',
'timezonetext'          => '¹Xepede zaah quij iitax mexepe locale quiixomde xepede servere (UTC).',
'localtime'             => 'Xepe locale',
'timezoneoffset'        => "Minus'set¹",
'servertime'            => 'Xepede server',
'guesstimezone'         => "Xuniimyabuatlecaún dai'browser",
'allowemail'            => 'Pos-coccebj e-iitomde diijömde caitóm',
'defaultns'             => 'Yahöx jan ipartuatl iti auto:',
'default'               => 'auto',
'files'                 => 'Ciúchán',

# User rights
'userrights-lookup-user'   => "Yoc' polámde caitom",
'userrights-user-editname' => 'Caitom ID ra:',
'editusergroup'            => 'Ticpatlöx Polám Caitóm',
'editinguser'              => "Ticpatlöx caitom '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
'userrights-editusergroup' => 'Ticpatlöx polám caitóm',
'saveusergroups'           => 'Xuniim Polámde Caitom',
'userrights-groupsmember'  => 'Ctamde:',
'userrights-reason'        => "Rade'reset:",

# Groups
'group'               => 'Polám:',
'group-autoconfirmed' => 'Autoconfirmám',
'group-bot'           => 'Botám',
'group-sysop'         => 'Sysopám',
'group-bureaucrat'    => 'Bureaucrátám',
'group-all'           => '(jöxde man)',

'group-autoconfirmed-member' => 'Autoconfirmam',
'group-bot-member'           => 'Botam',
'group-sysop-member'         => 'Sysopam',
'group-bureaucrat-member'    => 'Bureaucrátam',

'grouppage-autoconfirmed' => '{{ns:project}}:Autoconfirmam',
'grouppage-bot'           => '{{ns:project}}:Botam',
'grouppage-sysop'         => '{{ns:project}}:Sysopam',
'grouppage-bureaucrat'    => '{{ns:project}}:Bureaucrátam',

# User rights log
'rightsnone' => '(zéro)',

# Recent changes
'nchanges'                          => '$1 {{PLURAL:$1|quiix|quíix}}',
'recentchanges'                     => 'Camjöx cmaa',
'recentchangestext'                 => 'Caitom camjöx cmaa quiíx zode Wiki zo jan páhina iti.',
'recentchanges-feed-description'    => 'Caitom camjöx cmaa quiíx zode Wiki zo jan fiiyt iti.',
'rcnote'                            => "!-cmaa coccebj {{PLURAL:$1|'''1''' quiixde|'''$1''' hunquiíxde}} {{PLURAL:$2|'''1''' hunzaah|'''$2''' hunixaáp}} zo iti, $3 'de.",
'rcnotefrom'                        => "!-cmaa coccebj quiíx zode '''$2''' (plusöxiti '''$1''' visi).",
'rclistfrom'                        => "Cohuatlöx hunquiix startom $1 'de",
'rcshowhideminor'                   => '$1 editám bajlöxám',
'rcshowhidebots'                    => '$1 cibotám',
'rcshowhideliu'                     => '$1 caitom caápo',
'rcshowhideanons'                   => '$1 caitóm anoniimóm',
'rcshowhidepatr'                    => '$1 ticpatlöx patrollöx',
'rcshowhidemine'                    => '$1 hániideditám',
'rclinks'                           => 'Cohuatlöx hunquiix $1 zo ixáap $2 zo iti <br />$3',
'diff'                              => 'quiix',
'hist'                              => 'histó',
'hide'                              => 'Cíiitám',
'show'                              => 'Cohuatlöx',
'minoreditletter'                   => 'b',
'newpageletter'                     => 'H',
'boteditletter'                     => 'R',
'number_of_watching_users_pageview' => '[$1 cait(o/ó)m cáminot]',
'rc_categories'                     => 'Limitde cayliíb (separatman "|" mii)',
'rc_categories_any'                 => 'Jömde pac',
'newsectionsummary'                 => '/* $1 */ hunseccion',

# Recent changes linked
'recentchangeslinked'       => 'Quiix hámíigonix',
'recentchangeslinked-title' => 'Quiix hámíigonixde "$1"',

# Upload
'upload'            => 'Ciúchan uploadan',
'uploadbtn'         => 'Ciúchan uploadan',
'reupload'          => 'Re-uploadan',
'uploadnologin'     => 'Necaápo',
'uploadnologintext' => 'Zo coccebj Neces [[Special:UserLogin|caápo]] (re-)uploadande ciúchán.',
'uploaderror'       => 'Römjde uploadan',
'uploadlog'         => 'logde uploadan',
'uploadlogpage'     => 'Logde uploadan',
'filename'          => 'IDde ciúchan',
'filedesc'          => 'Abvuatl',
'fileuploadsummary' => 'Abvuatl:',
'filesource'        => 'Sourcenam:',
'uploadedfiles'     => 'Ciúchán uploadöxán',
'filetype-missing'  => 'Ciúchan zo necoccebj extencion (pac\' ".jpg").',
'uploadwarning'     => 'Attencionde uploadan',
'savefile'          => 'Xuniim ciúchan',
'uploadedimage'     => 'uploadöx "[[$1]]"',
'overwroteimage'    => 'uploadöx hunvercion zode "[[$1]]"',
'uploadvirus'       => 'Jan ciúchan coccebj virusde PC zo! Detailám: $1',
'sourcefilename'    => 'Sourcenam IDde ciúchan:',
'destfilename'      => 'Destinacion IDde ciúchan:',
'watchthisupload'   => 'Cáminot jan páhina',

'upload-proto-error' => 'Protocolam incorrectam',
'upload-file-error'  => 'Römjde internal',
'upload-misc-error'  => 'Römjde uploadan ác',

# Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
'upload-curl-error28' => 'Time-outde uploadan',

'license'           => 'Licenciónom:',
'nolicense'         => 'Seleccion coccebj hun',
'license-nopreview' => '(Necuáxiit)',

# Special:ListFiles
'listfiles_search_for'  => 'Yahöxde IDde ciúchan:',
'imgfile'               => 'ciúchan',
'listfiles'             => 'Listade ciúchán',
'listfiles_date'        => 'Datum',
'listfiles_name'        => 'Nom',
'listfiles_user'        => 'Caitom',
'listfiles_size'        => 'Bajlip',
'listfiles_description' => 'Discripcion',

# File description page
'filehist'                  => 'Historiade ciúchan',
'filehist-deleteall'        => 'delatom jömde man',
'filehist-deleteone'        => 'delatom jande man',
'filehist-revert'           => 'iixponintöx',
'filehist-current'          => 'currentua',
'filehist-datetime'         => 'Datum/Xepe',
'filehist-user'             => 'Caitom',
'filehist-dimensions'       => 'Dimención',
'filehist-filesize'         => 'Bajlipde ciúchan',
'filehist-comment'          => 'Commentua',
'imagelinks'                => 'Linkám',
'shareduploadwiki-linktext' => 'discripcionde ciúchan páhina',
'noimage-linktext'          => 'z(o) uploadan',
'uploadnewversion-linktext' => 'Uploadan hunvercion zode jan ciúchan',

# File reversion
'filerevert'                => 'Iixponintöx $1',
'filerevert-legend'         => 'Iixponintöx ciúchan',
'filerevert-comment'        => 'Commentua:',
'filerevert-defaultcomment' => "Iixponintöxde vercion $2, $1 'de",
'filerevert-submit'         => 'Iixponintöx',

# File deletion
'filedelete'         => 'Delatom $1',
'filedelete-legend'  => 'Ciúchan delatan',
'filedelete-comment' => 'Commentua:',
'filedelete-submit'  => 'Delatom',
'filedelete-success' => "'''$1''' coccebj delatomöx.",

# MIME search
'mimesearch' => 'Yahöx MIME',
'mimetype'   => 'typenamde MIME:',
'download'   => 'downloadan',

# List redirects
'listredirects' => 'Listade meniitomöx',

# Unused templates
'unusedtemplateswlh' => 'diijömde linkám',

# Random page
'randompage'         => 'Páhina cáulituniit',
'randompage-nopages' => 'Zo necoccebj páhinám jan ipartuatl iti.',

# Random redirect
'randomredirect'         => 'Meniitomöx cáulituniit',
'randomredirect-nopages' => 'Zo necoccebj meniitomöx jan ipartuatl iti.',

# Statistics
'statistics'              => 'Statisticám',
'statistics-header-users' => 'Caitom statisticám',

'doubleredirects' => 'Meniitomöx daj ti zon',

'brokenredirects'        => 'Meniitomöx linkám nedireccion',
'brokenredirectstext'    => 'Jan meniitomöx linkomde neday ti camiintivuatl páhinám:',
'brokenredirects-edit'   => '(ticpatlöx)',
'brokenredirects-delete' => '(delatom)',

# Miscellaneous special pages
'nbytes'              => '$1 {{PLURAL:$1|byte|bytenám}}',
'ncategories'         => '$1 {{PLURAL:$1|cayliib|cayliíb}}',
'nlinks'              => '$1 {{PLURAL:$1|link|linkám}}',
'nmembers'            => '$1 {{PLURAL:$1|diipolam|diipolám}}',
'nrevisions'          => '$1 {{PLURAL:$1|revicion|revición}}',
'nviews'              => '$1 {{PLURAL:$1|cohuatl|cohuátl}}',
'prefixindex'         => 'Indexde prefix',
'shortpages'          => 'Páhinám diibajlipám',
'longpages'           => 'Páhinám bajlipám',
'deadendpages'        => 'Páhinám huiquiix',
'deadendpagestext'    => 'Jan páhinám huiquiix linkámde jömdeman páhinám jan wiki iti.',
'protectedpages'      => 'Páhinám protectöx',
'protectedpagestext'  => 'Jan páhinám coccebj protectöxde yacom jöx ticpatlöx',
'protectedpagesempty' => '0 páhinám currentua coccebj protectöx jan parameterám mii.',
'listusers'           => 'Listade caitóm',
'newpages'            => 'Jan páhinám',
'newpages-username'   => 'Caitom ID:',
'ancientpages'        => 'Xeperesistant páhinám',
'move'                => 'Yacom',
'movethispage'        => 'Yacom jan páhina',

# Book sources
'booksources-go' => 'Caátemöx',

# Special:Log
'specialloguserlabel'  => 'Caitom:',
'speciallogtitlelabel' => 'Titlenam:',
'log'                  => 'Logám',
'all-logs-page'        => 'Jömde logám',

# Special:AllPages
'allpages'          => 'Jöxde páhinám',
'nextpage'          => 'Hunpáhina ($1)',
'prevpage'          => 'Janpáhina ($1)',
'allpagesfrom'      => 'Xuniim páhinám startomde:',
'allarticles'       => 'Jöxde artículóm',
'allinnamespace'    => 'Jömde páhinám ($1 ipartuatl)',
'allnotinnamespace' => "Jömde páhinám ($1 ipartuatl 'ne)",
'allpagesprev'      => 'Jan',
'allpagesnext'      => 'Hun',
'allpagessubmit'    => 'Caátemöx',
'allpagesprefix'    => 'Xuniim páhinám jan prefix mii:',
'allpages-bad-ns'   => '{{SITENAME}} necoccebj ipartuatl "$1".',

# Special:Categories
'categories' => 'Cayliibám',

# Special:ListUsers
'listusersfrom'      => 'Xuniim caitóm startomde:',
'listusers-submit'   => 'Cohuatlöx',
'listusers-noresult' => 'Necoccebj caitóm.',

# E-mail user
'mailnologin'     => 'Nenadressade iitom',
'mailnologintext' => 'Zo coccebj Neces [[Special:UserLogin|caápo]]
ö coccebjöx adressade e-iitom validom [[Special:Preferences|mequáatlaác]]
iitom e-iitomde diijömde caitóm.',
'emailuser'       => 'E-iitom  jan caitom',
'emailpage'       => 'E-iitom caitom',
'defemailsubject' => '{{SITENAME}} e-iitom',
'noemailtitle'    => 'Nejömde adressade e-iitom',
'emailfrom'       => 'Iitomde',
'emailto'         => 'Iitomé',
'emailsubject'    => 'Subjectua',
'emailmessage'    => 'Iitom',
'emailsend'       => 'Iitom',
'emailsent'       => 'E-iitomöx',
'emailsenttext'   => 'Hene-iitom coccebj e-iitomöx.',

# Watchlist
'watchlist'        => 'He listade cáminot',
'mywatchlist'      => 'He listade cáminot',
'watchlistfor'     => "('''$1''' mii)",
'nowatchlist'      => 'Hecoccebj 0 itémii helistade cáminot iti.',
'watchnologin'     => 'Necaápo',
'watchnologintext' => 'Zo coccebj Neces [[Special:UserLogin|caápo]] ticpatlöx helistade cáminot.',
'addedwatch'       => 'Plusöxaj listade cáminot',
'removedwatch'     => 'Delatajde he listade cáminot',
'removedwatchtext' => 'Páhina zo "[[:$1]]" coccebj delataj me listade cáminot.',
'watch'            => 'Cáminot',
'watchthispage'    => 'Cáminot jan páhina',
'unwatch'          => 'Diicáminot',
'unwatchthispage'  => 'Diicáminot jan páhina',
'wlshowlast'       => 'Cohuatlöx hun $1 ixáap quij iitax $2 ixáap $3',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Cáminot...',
'unwatching' => 'Necáminot...',

'enotif_newpagetext'           => 'Jan coccebj hunpáhina.',
'enotif_impersonal_salutation' => '{{SITENAME}} caitom',
'changed'                      => 'quiixöx',
'created'                      => 'creacöx',
'enotif_anon_editor'           => 'caitom anoniimom $1',

# Delete
'deletepage' => 'Delatar páhina',

# Protect
'prot_1movedto2' => '[[$1]] yacomöxde [[$2]]',
'pagesize'       => '(bytenám)',

# Restrictions (nouns)
'restriction-edit' => 'Ticpatlöx',
'restriction-move' => 'Yacom',

# Undelete
'undeletereset'          => "Reset'",
'undeletecomment'        => 'Commentua:',
'undelete-search-box'    => 'Yahöx páhinám delatám',
'undelete-search-submit' => 'Yahöx',

# Namespace form on various pages
'invert' => 'Hualtepacua',

# Contributions
'contributions' => 'Contribuciónde caitom',
'mycontris'     => 'Hecontribución',
'uctop'         => '(quániit)',

'sp-contributions-search'   => 'Yahöx contribución mii',
'sp-contributions-username' => 'Addressade IP jöx caitom ID:',
'sp-contributions-submit'   => 'Yahöx',

# What links here
'istemplate'          => 'incluciónaj',
'whatlinkshere-links' => '← linkám',

# Block/unblock
'blockip'                 => 'Block caitom',
'ipaddress'               => 'Addressade IP:',
'ipadressorusername'      => 'Addressade IP jöx caitom ID:',
'ipbreason'               => 'Ra:',
'ipbreasonotherlist'      => "Ra pac'de",
'ipbsubmit'               => 'Block jan caitom',
'ipbother'                => "Pac'de xepe:",
'ipbotheroption'          => "pac'de",
'ipbotherreason'          => "Pac'de rae (addicionale):",
'badipaddress'            => 'Addressade IP invalida',
'ipb-edit-dropdown'       => 'Blockde ticpatlöx rá',
'ipb-unblock-addr'        => 'Diiblockom $1',
'ipb-unblock'             => 'Diiblockom caitom ID zo jöx adressade iP zo',
'unblockip'               => 'Diiblockom caitom',
'ipusubmit'               => 'Diiblockom jan adressa',
'ipblocklist-legend'      => 'Yahöx caimát blockát pac',
'ipblocklist-username'    => 'Caitom ID jöx addressade IP:',
'ipblocklist-submit'      => 'Yahöx',
'anononlyblock'           => 'Anonytiit',
'emailblock'              => "e-iitom c'blockan",
'blocklink'               => 'blockom',
'unblocklink'             => 'diiblockom',
'contribslink'            => 'contribución',
'unblocklogentry'         => 'diiblocköx $1',
'block-log-flags-noemail' => 'blocköx e-iitom',

# Developer tools
'lockdb'            => 'Lockom databse',
'unlockdb'          => 'Diilockom database',
'lockconfirm'       => 'Lockom database zo coccebj heopcion.',
'unlockconfirm'     => 'Diilockom database zo coccebj heopcion',
'lockbtn'           => 'Lockom database',
'unlockbtn'         => 'Diilockom database',
'databasenotlocked' => 'Database zo necoccebj lockomöx.',

# Move page
'move-page-legend' => 'Yacom páhina',
'movearticle'      => 'Yacom páhina:',
'movenologin'      => 'Necaápo',
'move-watch'       => 'Cáminot jan páhina',
'movepagebtn'      => 'Yacom páhina',
'movedto'          => 'yacomöxde',
'movetalk'         => 'Yacom czaxö páhina yodina ipríi',
'1movedto2'        => '[[$1]] yacomöxde [[$2]]',
'movereason'       => 'Ra:',
'delete_and_move'  => 'Delatom ö yacom',

# Export
'export'        => 'Exportom páhinám',
'export-submit' => 'Exportom',

# Namespace 8 related
'allmessages'        => 'Iitóm systémóm',
'allmessagesname'    => 'Nom',
'allmessagescurrent' => 'Textam-cmaanam',

# Special:Import
'import'                  => 'Importóm páhinóm',
'import-interwiki-submit' => 'Importom',
'import-comment'          => 'Commentua:',
'importstart'             => 'Importom páhinám...',
'importfailed'            => 'Römjde import: $1',

# Tooltip help for the actions
'tooltip-pt-userpage'        => 'He caitom páhina',
'tooltip-pt-mytalk'          => 'He czaxö páhina',
'tooltip-pt-preferences'     => 'Hequáatlaác',
'tooltip-pt-mycontris'       => 'Listada hecontribución',
'tooltip-pt-logout'          => 'Cuípo',
'tooltip-ca-protect'         => 'Protectom jan páhina',
'tooltip-ca-delete'          => 'Delatom jan páhina',
'tooltip-ca-move'            => 'Yacom jan páhina',
'tooltip-search'             => 'Yahöx {{SITENAME}}',
'tooltip-p-logo'             => 'Caálixötöj',
'tooltip-n-mainpage'         => 'Yahöx caálixötöj zo',
'tooltip-n-help'             => 'Áahuiitl hant zo iti.',
'tooltip-t-emailuser'        => 'E-iitom jan caitom',
'tooltip-t-specialpages'     => 'Lista jömde páhinám extravám',
'tooltip-ca-nstab-main'      => 'Cohuatlöx contentua páhina zo',
'tooltip-ca-nstab-user'      => 'Cohuatlöx caitom páhina zo',
'tooltip-ca-nstab-media'     => 'Cohuatlöx media páhina zo',
'tooltip-ca-nstab-project'   => 'Cohuatlöx projectua páhina zo',
'tooltip-ca-nstab-mediawiki' => 'Cohuatlöx iitom systemom z',
'tooltip-ca-nstab-help'      => 'Cohuatlöx help páhina zo',
'tooltip-ca-nstab-category'  => 'Cohuatlöx cayliib páhina zo',
'tooltip-upload'             => 'Startom uploadan',

# Attribution
'siteuser'      => '{{SITENAME}} caitom $1',
'othercontribs' => 'Pacdan $1 mii.',
'others'        => "pac'detazo",
'siteusers'     => '{{SITENAME}} cait(o/ó)m $1',

# Spam protection
'spambot_username' => 'MediaWiki nespam',

# Info page
'infosubtitle' => 'Informacionde páhina',

# Media information
'widthheightpage' => '$1×$2, $3 páhinám',

# Special:NewFiles
'showhidebots' => '($1 botám)',
'ilsubmit'     => 'Yahöx',
'bydate'       => 'de datum',

# EXIF tags
'exif-fnumber'      => 'F Numberam',
'exif-gpslatitude'  => 'Latitudam',
'exif-gpslongitude' => 'Longitudam',
'exif-gpsaltitude'  => 'Altitudam',

'exif-subjectdistance-value' => '$1 miitrenám',

'exif-focalplaneresolutionunit-2' => 'inchám',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'jöxdem',
'imagelistall'     => 'jöxdem',
'watchlistall2'    => 'jöxdem',
'namespacesall'    => 'jöxdem',
'monthsall'        => 'jöxdem',

# action=purge
'confirm_purge_button' => 'ton',

# Multipage image navigation
'imgmultigo' => 'Caátemöx!',

# Table pager
'table_pager_limit_submit' => 'Caátemöx',

# Auto-summaries
'autosumm-new' => 'Hunpáhina: $1',

# Special:Version
'version' => 'Vercion', # Not used as normal message but as header for the special page itself

# Special:SpecialPages
'specialpages' => 'Páhinám extravám',

);
